@@ -37,3 +37,7 @@ def print_exc(limit=None, file=None, chain=True):
 
 def format_exc(limit=None, chain=True):
     return "".join(format_exception(*sys.exc_info(), limit=limit, chain=chain))
+
+
+def clear_frames(tb):
+    pass
